==> jc-1.4.0.tar.gz: soot/coffi/BBQ.h <==
// final class soot.coffi.BBQ

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 58a6ba796f1a759a soot_coffi_BBQ

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_BBQ_H_
#define _JC_soot_coffi_BBQ_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_coffi_BasicBlock$object;

// Typedefs
typedef struct _jc_soot_coffi_BBQ$sub_refs	_jc_soot_coffi_BBQ$sub_refs;
typedef struct _jc_soot_coffi_BBQ$sub_nonrefs	_jc_soot_coffi_BBQ$sub_nonrefs;
typedef struct _jc_soot_coffi_BBQ$refs	_jc_soot_coffi_BBQ$refs;
typedef struct _jc_soot_coffi_BBQ$nonrefs	_jc_soot_coffi_BBQ$nonrefs;
typedef struct _jc_soot_coffi_BBQ$object	_jc_soot_coffi_BBQ$object;

typedef const struct _jc_soot_coffi_BBQ$vmethods	_jc_soot_coffi_BBQ$vmethods;
typedef const struct _jc_soot_coffi_BBQ$vtable	_jc_soot_coffi_BBQ$vtable;
typedef const struct _jc_soot_coffi_BBQ$vtype	_jc_soot_coffi_BBQ$vtype;

// Constructors
extern void _jc_soot_coffi_BBQ$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_BBQ$object *);

// Virtual methods
extern void _jc_soot_coffi_BBQ$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
extern jboolean _jc_soot_coffi_BBQ$method$contains$38858bce9833690d(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *);
extern jboolean _jc_soot_coffi_BBQ$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
extern struct _jc_soot_coffi_BasicBlock$object *_jc_soot_coffi_BBQ$method$pull$26942705290c60df(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
extern void _jc_soot_coffi_BBQ$method$push$9428d3a2e5b99149(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *);
extern jint _jc_soot_coffi_BBQ$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_coffi_BBQ$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_BBQ$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_soot_coffi_BBQ$method_info$contains$38858bce9833690d;
extern _jc_method _jc_soot_coffi_BBQ$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_coffi_BBQ$method_info$pull$26942705290c60df;
extern _jc_method _jc_soot_coffi_BBQ$method_info$push$9428d3a2e5b99149;
extern _jc_method _jc_soot_coffi_BBQ$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_coffi_BBQ$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
	jboolean	(*contains$38858bce9833690d)(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
	struct _jc_soot_coffi_BasicBlock$object	*(*pull$26942705290c60df)(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
	void	(*push$9428d3a2e5b99149)(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_coffi_BBQ$object *);
};

// Vtable
struct _jc_soot_coffi_BBQ$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_BBQ$vmethods	soot_coffi_BBQ;
};

// Vtype
struct _jc_soot_coffi_BBQ$vtype {
	_jc_type			type;
	_jc_soot_coffi_BBQ$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_BBQ$sub_refs {
	struct _jc_java_util_ArrayList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_coffi_BBQ$refs {
    _jc_soot_coffi_BBQ$sub_refs	soot_coffi_BBQ;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_BBQ$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_BBQ$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_BBQ$sub_nonrefs	soot_coffi_BBQ;
};

// Object instance structure
struct _jc_soot_coffi_BBQ$object {
	_jc_soot_coffi_BBQ$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_BBQ$vtype	*vtype;
	_jc_soot_coffi_BBQ$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_BBQ$vtype _jc_soot_coffi_BBQ$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_BBQ, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_BBQ$class_object;

#endif	/* _JC_soot_coffi_BBQ_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/BBQ.h <==
// final class soot.coffi.BBQ

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 58a6ba796f1a759a soot_coffi_BBQ

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_BBQ_H_
#define _JC_soot_coffi_BBQ_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_coffi_BasicBlock$object;

// Typedefs
typedef struct _jc_soot_coffi_BBQ$sub_refs	_jc_soot_coffi_BBQ$sub_refs;
typedef struct _jc_soot_coffi_BBQ$sub_nonrefs	_jc_soot_coffi_BBQ$sub_nonrefs;
typedef struct _jc_soot_coffi_BBQ$refs	_jc_soot_coffi_BBQ$refs;
typedef struct _jc_soot_coffi_BBQ$nonrefs	_jc_soot_coffi_BBQ$nonrefs;
typedef struct _jc_soot_coffi_BBQ$object	_jc_soot_coffi_BBQ$object;

typedef const struct _jc_soot_coffi_BBQ$vmethods	_jc_soot_coffi_BBQ$vmethods;
typedef const struct _jc_soot_coffi_BBQ$vtable	_jc_soot_coffi_BBQ$vtable;
typedef const struct _jc_soot_coffi_BBQ$vtype	_jc_soot_coffi_BBQ$vtype;

// Constructors
extern void _jc_soot_coffi_BBQ$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_coffi_BBQ$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_coffi_BBQ$method$contains$38858bce9833690d(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern jboolean _jc_soot_coffi_BBQ$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_coffi_BasicBlock$object *_jc_soot_coffi_BBQ$method$pull$26942705290c60df(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_BBQ$method$push$9428d3a2e5b99149(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_coffi_BBQ$method$size$345df5220fc60ade(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_BBQ$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_soot_coffi_BBQ$method_info$contains$38858bce9833690d;
extern _jc_method _jc_soot_coffi_BBQ$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_soot_coffi_BBQ$method_info$pull$26942705290c60df;
extern _jc_method _jc_soot_coffi_BBQ$method_info$push$9428d3a2e5b99149;
extern _jc_method _jc_soot_coffi_BBQ$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_soot_coffi_BBQ$vmethods {
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
	jboolean	(*contains$38858bce9833690d)(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
	struct _jc_soot_coffi_BasicBlock$object	*(*pull$26942705290c60df)(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
	void	(*push$9428d3a2e5b99149)(_jc_env *, struct _jc_soot_coffi_BBQ$object *, struct _jc_soot_coffi_BasicBlock$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_soot_coffi_BBQ$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_BBQ$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_BBQ$vmethods	soot_coffi_BBQ;
};

// Vtype
struct _jc_soot_coffi_BBQ$vtype {
	_jc_type			type;
	_jc_soot_coffi_BBQ$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_BBQ$sub_refs {
	struct _jc_java_util_ArrayList$object	*q;
};

// Reference instance fields (object)
struct _jc_soot_coffi_BBQ$refs {
    _jc_soot_coffi_BBQ$sub_refs	soot_coffi_BBQ;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_BBQ$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_BBQ$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_BBQ$sub_nonrefs	soot_coffi_BBQ;
};

// Object instance structure
struct _jc_soot_coffi_BBQ$object {
	_jc_soot_coffi_BBQ$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_BBQ$vtype	*vtype;
	_jc_soot_coffi_BBQ$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_BBQ$vtype _jc_soot_coffi_BBQ$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_BBQ, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_BBQ$class_object;

#endif	/* _JC_soot_coffi_BBQ_H_ */
